if not BananaDKP then return end

local frame = CreateFrame("Frame", nil, InterfaceOptionsFramePanelContainer)
frame.name = "BananaDKP"
frame:Hide()

local function click(self)
	PlaySound(self:GetChecked() and "igMainMenuOptionCheckBoxOn" or "igMainMenuOptionCheckBoxOff")
	self.onClick(self, self:GetChecked() and true or false)
end

local function newCheckbox(parent, label, onClick)
	local check = CreateFrame("CheckButton", nil, parent)
	check:SetWidth(26)
	check:SetHeight(26)
	check:SetHitRectInsets(0, -100, 0, 0)
	check:SetNormalTexture("Interface\\Buttons\\UI-CheckBox-Up")
	check:SetPushedTexture("Interface\\Buttons\\UI-CheckBox-Down")
	check:SetHighlightTexture("Interface\\Buttons\\UI-CheckBox-Highlight")
	check:SetDisabledCheckedTexture("Interface\\Buttons\\UI-CheckBox-Check-Disabled")
	check:SetCheckedTexture("Interface\\Buttons\\UI-CheckBox-Check")
	check:SetScript("OnClick", click)
	check.onClick = onClick
	local fs = check:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	fs:SetPoint("LEFT", check, "RIGHT", 0, 1)
	fs:SetPoint("RIGHT", parent, "RIGHT", 0, 0)
	fs:SetJustifyH("LEFT")
	fs:SetText(label)
	fs:SetWidth(parent:GetWidth() / 2 - 26)
	check.fs = fs
	return check
end

local ranks = nil
local function rankOnClick(self, checked)
	_G.BananaDKPDB.disallowRanks[self.rank] = not checked
end
local function updateRankCheckboxes()
	local db = _G.BananaDKPDB
	local guildRanks = BananaDKP:GetGuildRanks()
	for k, v in pairs(ranks.checkboxes) do v:Hide() end
	local oldCheck = nil
	for i, v in next, guildRanks do
		if not ranks.checkboxes[v] then
			local check = newCheckbox(ranks, v, rankOnClick)
			check.rank = v
			check:SetChecked(not db.disallowRanks[v])
			ranks.checkboxes[v] = check
		end
		local check = ranks.checkboxes[v]
		if i == 1 then
			check:SetPoint("TOPLEFT", ranks, 4, -4)
		else
			check:SetPoint("TOPLEFT", oldCheck, "BOTTOMLEFT", 0, -4)
		end
		check:Show()
		oldCheck = check
	end
end


frame:SetScript("OnShow", function(frame)
	local title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText("BananaDKP")

	local subtitle = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	subtitle:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
	subtitle:SetWidth(frame:GetWidth() - 24)
	subtitle:SetJustifyH("LEFT")
	subtitle:SetJustifyV("TOP")
	subtitle:SetText("DKP system for all guilds in the Banana Republic. Here you can toggle which classes and which guild ranks should be visible in the tooltip.")

	if not IsInGuild() then
		local subsub = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
		subsub:SetPoint("TOPLEFT", subtitle, "BOTTOMLEFT", 0, -8)
		subsub:SetWidth(frame:GetWidth() - 24)
		subsub:SetJustifyH("LEFT")
		subsub:SetJustifyV("TOP")
		subsub:SetText("|cffff0000Since you are not guilded with this character, there are no options for you here. Go away! If for some reason you should join a guild this session that uses BananaDKP (yeah, that's likely!), you will need to relog before anything will appear here.|r")
		return
	end

	ranks = CreateFrame("Frame", nil, frame)
	ranks:SetWidth(frame:GetWidth() / 3 - 24)
	ranks:SetHeight(frame:GetHeight())
	ranks:SetPoint("TOPLEFT", subtitle, "BOTTOMLEFT", -2, -8)
	ranks.checkboxes = {}
	updateRankCheckboxes()

	local classes = CreateFrame("Frame", nil, frame)
	classes:SetWidth(frame:GetWidth() - ranks:GetWidth())
	classes:SetHeight(frame:GetHeight())
	classes:SetPoint("TOPLEFT", ranks, "TOPRIGHT", 12)

	local db = _G.BananaDKPDB
	local function onClick(self, checked)
		db.disallowClasses[self.class] = not checked
	end
	local oldCheck = nil
	local i = 1
	local firstCheck = nil
	for caps, loc in pairs(LOCALIZED_CLASS_NAMES_MALE) do
		local check = newCheckbox(classes, loc, onClick)
		local c = RAID_CLASS_COLORS[caps]
		check.fs:SetTextColor(c.r, c.g, c.b)
		check.class = caps
		check:SetChecked(not db.disallowClasses[caps])
		if i == 1 then
			firstCheck = check
			check:SetPoint("TOPLEFT", classes, 4, -4)
		elseif i == 6 then
			check:SetPoint("TOPLEFT", firstCheck, "TOPRIGHT", frame:GetWidth() / 3, 0)
		else
			check:SetPoint("TOPLEFT", oldCheck, "BOTTOMLEFT", 0, -4)
		end
		i = i + 1
		oldCheck = check
	end

	frame:SetScript("OnShow", nil)
end)
InterfaceOptions_AddCategory(frame)

function BananaDKP:UpdateConfigScreen()
	if not ranks then return end
	updateRankCheckboxes()
end

